@@ -53,6 +53,12 @@ def add_images_to_existing_project(session, projnumber):
             print(f'{existing_project["name"]} already has {num_exist_int} INT images')
         else:
             print(f"{existing_project['name']} has no INT images, let's create a folder for them!")
+            int_folder = session.create(
+                "Folder",
+                {
+                    "name": f"{projnumber}_INT",
+                    "parent": existing_project
+                })
 
         exterior_shots = [i for i in existing_project['children'] if "EXT" in i["name"]]
         num_existing_ext = 0
@@ -62,6 +68,12 @@ def add_images_to_existing_project(session, projnumber):
             print(f'{existing_project["name"]} already has {num_existing_ext} EXT images')
         else:
             print(f"{existing_project['name']} has no EXT images, let's create a folder for them!")
+            ext_folder = session.create(
+                "Folder",
+                {
+                    "name": f"{projnumber}_EXT",
+                    "parent": existing_project
+                })
 
         while True:
             try:
