@@ -1,8 +1,9 @@
+import click
 from pick import pick
 
-from ftrack_ams.fileserver import create_project_on_fileserver, get_latest_proj
+from ftrack_ams.fileserver import create_project_on_fileserver, get_deal_info, get_latest_proj
 from ftrack_ams.functions import clearConsole, get_int_from_user, select_artist
-from ftrack_ams.functions import create_project_name
+from ftrack_ams.functions import create_project_name, get_yes_no
 
 
 def create_new_project(session):
@@ -17,11 +18,12 @@ def create_new_project(session):
 
     projects = session.query("Project")
     users = session.query("User")
+    client = None
+    projname = None
 
     logo_handle = session.query('Folder where name is "AMSVFB_Logo"').one()
 
     for logo in logo_handle["children"]:
-        print(logo)
         if logo["name"] == "VFB-LOGO":
             vfb_thumb = logo["thumbnail_id"]
         if logo["name"] == "AMSVFB-LOGO":
@@ -30,6 +32,34 @@ def create_new_project(session):
             ams_thumb = logo["thumbnail_id"]
 
     clearConsole()
+    num = None
+    
+    if get_yes_no("Do you have a deal number?"):
+        while True:
+            dealnumber = input("Enter deal number: ")
+            try:
+                int(dealnumber)
+            except ValueError:
+                print("Sorry, I didn't understand that? Did you type a number?")
+                continue
+            else:
+                if len(dealnumber) == 4:
+                    click.secho(f"Looks like {dealnumber} already existing, try adding to this project instead of creating a new one", fg="yellow")
+                    input("press enter to re-run")
+                    quit()
+                if len(dealnumber) == 3:
+                    click.secho("nieuw project op basis van een deal, cool story brah")
+                    break
+                else:
+                    click.secho("🤯 Try typing 3 or 4 numbers", fg="red")
+                    continue
+
+    if dealnumber is not None:
+        deal = get_deal_info(dealnumber)
+        if deal is not None:
+            split = deal.split('_')
+            client = split[3]
+            projname = split[4]
 
     print(f"Ok {session.api_user}, which team are we making a project for?")
 
@@ -40,7 +70,25 @@ def create_new_project(session):
     )
 
     clearConsole()
+
     num = get_latest_proj()
+    if get_yes_no(f"Based on the latest X: project, your project number is {num}, u like?"):
+        print(f"Ok, we're rolling with {num}")
+    else:
+        while True:
+            raw_input = input("Enter project number: ")
+            try:
+                int(raw_input)
+            except ValueError:
+                print("Sorry, I didn't understand that? Did you type a number?")
+                continue
+            else:
+                if len(raw_input) != 4:
+                    click.secho("🤯 Try typing 4 numbers", fg="red")
+                    continue
+                num = raw_input
+                break
+
     team = [t for t in projects if option.lower() == t["name"].lower()][0]
     print(f"💁‍♂️ Making a new project for {team['name']}")
 
@@ -80,25 +128,25 @@ def create_new_project(session):
             dest_folder = child
 
     if dest_folder is None:
-        print(f"could not find a 'Projects' folder for team {team['name']}")
+        click.secho(f"could not find a 'Projects' folder for team {team['name']}", fg="red")
         quit()
-
-    while True:
-        client = input("Enter client letter code (3 characters):")
-        if len(client) == 3:
-            print(f"making project number {num} for client {client}")
-            break
-        else:
-            print("didnt get ya fully")
-            continue
-
-    while True:
-        projname = input("Enter project letter code (3 characters):")
-        if len(projname) == 3:
-            break
-        else:
-            print("Didnt get ya fully? Type three characters.")
-            continue
+    if client is None:
+        while True:
+            client = input("Enter client letter code (3 characters):")
+            if len(client) == 3:
+                print(f"making project number {num} for client {client}")
+                break
+            else:
+                print("didnt get ya fully")
+                continue
+    if projname is None:
+        while True:
+            projname = input("Enter project letter code (3 characters):")
+            if len(projname) == 3:
+                break
+            else:
+                print("Didnt get ya fully? Type three characters.")
+                continue
 
     project_name = create_project_name(num, client, projname)
 
@@ -282,10 +330,14 @@ def create_new_project(session):
 
     session.commit()
 
+
     print(f"Succesfully created {project_name} for {team['name']}")
+    if deal is not None:
+        print(f"Based on deal {deal}")
     print(f"--- creating objects for {project_name} on ftrack")
     print(f"--- creating outlook folder for {project_name}")
     print(f"--- creating directory for {project_name} on X:/")
+    create_project_on_fileserver(project_name, internal_project, deal)
     print(
         f"-- {num_int} INT tasks for {int_artist['username']}"
     ) if num_int > 0 else None
@@ -295,8 +347,3 @@ def create_new_project(session):
     print("--- creating photography tasks") if drone else None
     print(f"--- creating {project_name}.mxp for 3dsmax project")
     print(f"--- updating {project_name} on teamleader")
-
-
-def get_yes_no(question):
-    answer = pick(["Yes", "No"], question)
-    return True if answer[1] == 0 else False
